@@ -5,4 +5,6 @@ from .Thumbnails import Thumbnail
 from .Comments import Comment
 from .CommentThreads import CommentThread
 from .I18ns import I18n
-from .VideoExtras import VideoCategory, VideoAbuseReportReason
\ No newline at end of file
+from .VideoExtras import VideoCategory, VideoAbuseReportReason
+from .Channels import Channel
+from .ChannelSections import ChannelSection
\ No newline at end of file
