@@ -2,4 +2,6 @@ from .PlaylistItemResources import PlaylistItemResource
 from .PlaylistResources import PlaylistResource
 from .VideoResources import VideoResource, VideoReportAbuseBody
 from .CommentResources import CommentResource
-from .CommentThreadResources import CommentThreadResource
\ No newline at end of file
+from .CommentThreadResources import CommentThreadResource
+from .ChannelResources import ChannelResource
+from .ChannelSectionResources import ChannelSectionResource
\ No newline at end of file
